class TouchstoneException(Exception):
    pass


class ServiceException(Exception):
    pass


class TestException(Exception):
    pass


class DepException(Exception):
    pass


class DepNotSupportedException(Exception):
    pass


class ContainerException(Exception):
    pass
